==> DateTime-Locale-1.17.tar.gz: DateTime-Locale-1.17/share/ee-TG.pl <==
{
  am_pm_abbreviated => [
    "\N{U+014b}di",
    "\N{U+0263}etr\N{U+0254}",
  ],
  available_formats => {
    Bh => "'ga' h 'le' B 'me'",
    Bhm => "'ga' h 'a\N{U+0256}aba\N{U+0192}o\N{U+0192}o' mm 'le' B 'me'",
    Bhms => "h:mm:ss 'le' B 'me'",
    E => "ccc",
    EBhm => "'ga' h:mm 'le' E B 'me'",
    EBhms => "'ga' h:mm:ss 'le' E B 'me'",
    EHm => "E 'ga' HH:mm",
    EHms => "E 'ga' HH:mm:ss",
    Ed => "E d",
    Ehm => "E a 'ga' h:mm",
    Ehms => "E a 'ga' h:mm:ss",
    Gy => "y G",
    GyMMM => "MMM y G",
    GyMMMEd => "E, MMM d 'lia' y G",
    GyMMMd => "MMM d 'lia', y G",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "'ga' HH:mm:ss 'le' v",
    Hmv => "'ga' HH:mm 'le' v",
    M => "L",
    MEd => "E, M/d",
    MMM => "LLL",
    MMMEd => "E, MMM d 'lia'",
    MMMMEd => "E, MMMM d 'lia'",
    "MMMMW-count-one" => "MMMM '\N{U+0192}e' 'k\N{U+0254}si\N{U+0256}a' W 'lia'",
    "MMMMW-count-other" => "MMMM '\N{U+0192}e' 'k\N{U+0254}si\N{U+0256}a' W 'lia'",
    MMMMd => "MMMM d 'lia'",
    MMMd => "MMM d 'lia'",
    Md => "M/d",
    d => "d",
    h => "a 'ga' h",
    hm => "a 'ga' h:mm",
    hms => "a 'ga' h:mm:ss",
    hmsv => "a 'ga' h:mm:ss 'le' v",
    hmv => "a 'ga' h:mm 'le' v",
    ms => "'a\N{U+0256}aba\N{U+0192}o\N{U+0192}o' mm:ss",
    y => "y",
    yM => "M/y",
    yMEd => "E, M/d/y",
    yMMM => "MMM y",
    yMMMEd => "E, MMM d, y",
    yMMMM => "MMMM y",
    yMMMd => "MMM d 'lia', y",
    yMd => "M/d/y",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ y",
    "yw-count-one" => "'k\N{U+0254}si\N{U+0256}a' w 'lia' 'le' '\N{U+0192}e' Y 'me'",
    "yw-count-other" => "'k\N{U+0254}si\N{U+0256}a' w 'lia' 'le' '\N{U+0192}e' Y 'me'",
  },
  code => "ee-TG",
  date_format_full => "EEEE, MMMM d 'lia' y",
  date_format_long => "MMMM d 'lia' y",
  date_format_medium => "MMM d 'lia', y",
  date_format_short => "M/d/yy",
  datetime_format_full => "{0} {1}",
  datetime_format_long => "{0} {1}",
  datetime_format_medium => "{0} {1}",
  datetime_format_short => "{0} {1}",
  day_format_abbreviated => [
    "dzo",
    "bla",
    "ku\N{U+0256}",
    "yaw",
    "fi\N{U+0256}",
    "mem",
    "k\N{U+0254}s",
  ],
  day_format_narrow => [
    "d",
    "b",
    "k",
    "y",
    "f",
    "m",
    "k",
  ],
  day_format_wide => [
    "dzo\N{U+0256}a",
    "bla\N{U+0256}a",
    "ku\N{U+0256}a",
    "yawo\N{U+0256}a",
    "fi\N{U+0256}a",
    "memle\N{U+0256}a",
    "k\N{U+0254}si\N{U+0256}a",
  ],
  day_stand_alone_abbreviated => [
    "dzo",
    "bla",
    "ku\N{U+0256}",
    "yaw",
    "fi\N{U+0256}",
    "mem",
    "k\N{U+0254}s",
  ],
  day_stand_alone_narrow => [
    "d",
    "b",
    "k",
    "y",
    "f",
    "m",
    "k",
  ],
  day_stand_alone_wide => [
    "dzo\N{U+0256}a",
    "bla\N{U+0256}a",
    "ku\N{U+0256}a",
    "yawo\N{U+0256}a",
    "fi\N{U+0256}a",
    "memle\N{U+0256}a",
    "k\N{U+0254}si\N{U+0256}a",
  ],
  era_abbreviated => [
    "HYV",
    "Y\N{U+014b}",
  ],
  era_narrow => [
    "HYV",
    "Y\N{U+014b}",
  ],
  era_wide => [
    "Hafi Yesu Va",
    "Yesu \N{U+014b}\N{U+0254}li",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Ewe",
  month_format_abbreviated => [
    "dzv",
    "dzd",
    "ted",
    "af\N{U+0254}",
    "dam",
    "mas",
    "sia",
    "dea",
    "any",
    "kel",
    "ade",
    "dzm",
  ],
  month_format_narrow => [
    "d",
    "d",
    "t",
    "a",
    "d",
    "m",
    "s",
    "d",
    "a",
    "k",
    "a",
    "d",
  ],
  month_format_wide => [
    "dzove",
    "dzodze",
    "tedoxe",
    "af\N{U+0254}f\N{U+0129}e",
    "dama",
    "masa",
    "siaml\N{U+0254}m",
    "deasiamime",
    "any\N{U+0254}ny\N{U+0254}",
    "kele",
    "ade\N{U+025b}mekp\N{U+0254}xe",
    "dzome",
  ],
  month_stand_alone_abbreviated => [
    "dzv",
    "dzd",
    "ted",
    "af\N{U+0254}",
    "dam",
    "mas",
    "sia",
    "dea",
    "any",
    "kel",
    "ade",
    "dzm",
  ],
  month_stand_alone_narrow => [
    "d",
    "d",
    "t",
    "a",
    "d",
    "m",
    "s",
    "d",
    "a",
    "k",
    "a",
    "d",
  ],
  month_stand_alone_wide => [
    "dzove",
    "dzodze",
    "tedoxe",
    "af\N{U+0254}f\N{U+0129}e",
    "dama",
    "masa",
    "siaml\N{U+0254}m",
    "deasiamime",
    "any\N{U+0254}ny\N{U+0254}",
    "kele",
    "ade\N{U+025b}mekp\N{U+0254}xe",
    "dzome",
  ],
  name => "Ewe Togo",
  native_language => "E\N{U+028b}egbe",
  native_name => "E\N{U+028b}egbe Togo nutome",
  native_script => undef,
  native_territory => "Togo nutome",
  native_variant => undef,
  quarter_format_abbreviated => [
    "k1",
    "k2",
    "k3",
    "k4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "k\N{U+0254}ta gb\N{U+00e3}t\N{U+0254}",
    "k\N{U+0254}ta evelia",
    "k\N{U+0254}ta et\N{U+0254}\N{U+0303}lia",
    "k\N{U+0254}ta enelia",
  ],
  quarter_stand_alone_abbreviated => [
    "k1",
    "k2",
    "k3",
    "k4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "k\N{U+0254}ta gb\N{U+00e3}t\N{U+0254}",
    "k\N{U+0254}ta evelia",
    "k\N{U+0254}ta et\N{U+0254}\N{U+0303}lia",
    "k\N{U+0254}ta enelia",
  ],
  script => undef,
  territory => "Togo",
  time_format_full => "HH:mm:ss zzzz",
  time_format_long => "HH:mm:ss z",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => 32,
}

==> DateTime-Locale-1.18.tar.gz: DateTime-Locale-1.18/share/ee-TG.pl <==
{
  am_pm_abbreviated => [
    "\N{U+014b}di",
    "\N{U+0263}etr\N{U+0254}",
  ],
  available_formats => {
    Bh => "'ga' h 'le' B 'me'",
    Bhm => "'ga' h 'a\N{U+0256}aba\N{U+0192}o\N{U+0192}o' mm 'le' B 'me'",
    Bhms => "h:mm:ss 'le' B 'me'",
    E => "ccc",
    EBhm => "'ga' h:mm 'le' E B 'me'",
    EBhms => "'ga' h:mm:ss 'le' E B 'me'",
    EHm => "E 'ga' HH:mm",
    EHms => "E 'ga' HH:mm:ss",
    Ed => "E d",
    Ehm => "E a 'ga' h:mm",
    Ehms => "E a 'ga' h:mm:ss",
    Gy => "y G",
    GyMMM => "MMM y G",
    GyMMMEd => "E, MMM d 'lia' y G",
    GyMMMd => "MMM d 'lia', y G",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "'ga' HH:mm:ss 'le' v",
    Hmv => "'ga' HH:mm 'le' v",
    M => "L",
    MEd => "E, M/d",
    MMM => "LLL",
    MMMEd => "E, MMM d 'lia'",
    MMMMEd => "E, MMMM d 'lia'",
    "MMMMW-count-one" => "MMMM '\N{U+0192}e' 'k\N{U+0254}si\N{U+0256}a' W 'lia'",
    "MMMMW-count-other" => "MMMM '\N{U+0192}e' 'k\N{U+0254}si\N{U+0256}a' W 'lia'",
    MMMMd => "MMMM d 'lia'",
    MMMd => "MMM d 'lia'",
    Md => "M/d",
    d => "d",
    h => "a 'ga' h",
    hm => "a 'ga' h:mm",
    hms => "a 'ga' h:mm:ss",
    hmsv => "a 'ga' h:mm:ss 'le' v",
    hmv => "a 'ga' h:mm 'le' v",
    ms => "'a\N{U+0256}aba\N{U+0192}o\N{U+0192}o' mm:ss",
    y => "y",
    yM => "M/y",
    yMEd => "E, M/d/y",
    yMMM => "MMM y",
    yMMMEd => "E, MMM d, y",
    yMMMM => "MMMM y",
    yMMMd => "MMM d 'lia', y",
    yMd => "M/d/y",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ y",
    "yw-count-one" => "'k\N{U+0254}si\N{U+0256}a' w 'lia' 'le' '\N{U+0192}e' y 'me'",
    "yw-count-other" => "'k\N{U+0254}si\N{U+0256}a' w 'lia' 'le' '\N{U+0192}e' y 'me'",
  },
  code => "ee-TG",
  date_format_full => "EEEE, MMMM d 'lia' y",
  date_format_long => "MMMM d 'lia' y",
  date_format_medium => "MMM d 'lia', y",
  date_format_short => "M/d/yy",
  datetime_format_full => "{0} {1}",
  datetime_format_long => "{0} {1}",
  datetime_format_medium => "{0} {1}",
  datetime_format_short => "{0} {1}",
  day_format_abbreviated => [
    "dzo",
    "bla",
    "ku\N{U+0256}",
    "yaw",
    "fi\N{U+0256}",
    "mem",
    "k\N{U+0254}s",
  ],
  day_format_narrow => [
    "d",
    "b",
    "k",
    "y",
    "f",
    "m",
    "k",
  ],
  day_format_wide => [
    "dzo\N{U+0256}a",
    "bla\N{U+0256}a",
    "ku\N{U+0256}a",
    "yawo\N{U+0256}a",
    "fi\N{U+0256}a",
    "memle\N{U+0256}a",
    "k\N{U+0254}si\N{U+0256}a",
  ],
  day_stand_alone_abbreviated => [
    "dzo",
    "bla",
    "ku\N{U+0256}",
    "yaw",
    "fi\N{U+0256}",
    "mem",
    "k\N{U+0254}s",
  ],
  day_stand_alone_narrow => [
    "d",
    "b",
    "k",
    "y",
    "f",
    "m",
    "k",
  ],
  day_stand_alone_wide => [
    "dzo\N{U+0256}a",
    "bla\N{U+0256}a",
    "ku\N{U+0256}a",
    "yawo\N{U+0256}a",
    "fi\N{U+0256}a",
    "memle\N{U+0256}a",
    "k\N{U+0254}si\N{U+0256}a",
  ],
  era_abbreviated => [
    "HYV",
    "Y\N{U+014b}",
  ],
  era_narrow => [
    "HYV",
    "Y\N{U+014b}",
  ],
  era_wide => [
    "Hafi Yesu Va",
    "Yesu \N{U+014b}\N{U+0254}li",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Ewe",
  month_format_abbreviated => [
    "dzv",
    "dzd",
    "ted",
    "af\N{U+0254}",
    "dam",
    "mas",
    "sia",
    "dea",
    "any",
    "kel",
    "ade",
    "dzm",
  ],
  month_format_narrow => [
    "d",
    "d",
    "t",
    "a",
    "d",
    "m",
    "s",
    "d",
    "a",
    "k",
    "a",
    "d",
  ],
  month_format_wide => [
    "dzove",
    "dzodze",
    "tedoxe",
    "af\N{U+0254}f\N{U+0129}e",
    "dama",
    "masa",
    "siaml\N{U+0254}m",
    "deasiamime",
    "any\N{U+0254}ny\N{U+0254}",
    "kele",
    "ade\N{U+025b}mekp\N{U+0254}xe",
    "dzome",
  ],
  month_stand_alone_abbreviated => [
    "dzv",
    "dzd",
    "ted",
    "af\N{U+0254}",
    "dam",
    "mas",
    "sia",
    "dea",
    "any",
    "kel",
    "ade",
    "dzm",
  ],
  month_stand_alone_narrow => [
    "d",
    "d",
    "t",
    "a",
    "d",
    "m",
    "s",
    "d",
    "a",
    "k",
    "a",
    "d",
  ],
  month_stand_alone_wide => [
    "dzove",
    "dzodze",
    "tedoxe",
    "af\N{U+0254}f\N{U+0129}e",
    "dama",
    "masa",
    "siaml\N{U+0254}m",
    "deasiamime",
    "any\N{U+0254}ny\N{U+0254}",
    "kele",
    "ade\N{U+025b}mekp\N{U+0254}xe",
    "dzome",
  ],
  name => "Ewe Togo",
  native_language => "E\N{U+028b}egbe",
  native_name => "E\N{U+028b}egbe Togo nutome",
  native_script => undef,
  native_territory => "Togo nutome",
  native_variant => undef,
  quarter_format_abbreviated => [
    "k1",
    "k2",
    "k3",
    "k4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "k\N{U+0254}ta gb\N{U+00e3}t\N{U+0254}",
    "k\N{U+0254}ta evelia",
    "k\N{U+0254}ta et\N{U+0254}\N{U+0303}lia",
    "k\N{U+0254}ta enelia",
  ],
  quarter_stand_alone_abbreviated => [
    "k1",
    "k2",
    "k3",
    "k4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "k\N{U+0254}ta gb\N{U+00e3}t\N{U+0254}",
    "k\N{U+0254}ta evelia",
    "k\N{U+0254}ta et\N{U+0254}\N{U+0303}lia",
    "k\N{U+0254}ta enelia",
  ],
  script => undef,
  territory => "Togo",
  time_format_full => "HH:mm:ss zzzz",
  time_format_long => "HH:mm:ss z",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => 33,
}
